# PySentry - pip-audit Benchmark Report

**Generated:** 2026-01-28 01:23:01
**Duration:** 1m 41.33s
**Total Tests:** 20

## Executive Summary

**Overall Success Rate:** 100.0% (20/20 successful runs)

### Small_Requirements Dataset - Cold Cache
- **Fastest:** pysentry-pypi (0.492s) - 18.11x faster than slowest
- **Memory Efficient:** pysentry-pypi (16.93 MB) - 5.41x less memory than highest

### Small_Requirements Dataset - Hot Cache
- **Fastest:** pysentry-pypi (0.277s) - 29.27x faster than slowest
- **Memory Efficient:** pysentry-pypi (8.33 MB) - 9.93x less memory than highest

### Large_Requirements Dataset - Cold Cache
- **Fastest:** pysentry-pypi (0.951s) - 18.39x faster than slowest
- **Memory Efficient:** pysentry-osv (37.28 MB) - 3.25x less memory than highest

### Large_Requirements Dataset - Hot Cache
- **Fastest:** pysentry-pypi (0.880s) - 18.57x faster than slowest
- **Memory Efficient:** pysentry-pypi (9.28 MB) - 9.99x less memory than highest

## Test Environment

- **Platform:** Linux-6.11.0-1018-azure-x86_64-with-glibc2.39
- **Python Version:** 3.11.14
- **CPU Cores:** 4
- **Total Memory:** 15.62 GB
- **Available Memory:** 14.67 GB

## Performance Comparison

### Small_Requirements Dataset - Cold Cache

#### Execution Time Comparison

| Tool Configuration | Execution Time | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 0.492s | 1.00x |
| 🥈 pysentry-osv | 0.634s | 1.29x |
|  pysentry-all-sources | 1.054s | 2.14x |
|  pysentry-pypa | 1.189s | 2.42x |
|  pip-audit-default | 8.909s | 18.11x |

#### Memory Usage Comparison

| Tool Configuration | Peak Memory | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 16.93 MB | 1.00x |
| 🥈 pysentry-osv | 19.34 MB | 1.14x |
|  pip-audit-default | 45.83 MB | 2.71x |
|  pysentry-pypa | 68.27 MB | 4.03x |
|  pysentry-all-sources | 91.60 MB | 5.41x |

### Small_Requirements Dataset - Hot Cache

#### Execution Time Comparison

| Tool Configuration | Execution Time | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 0.277s | 1.00x |
| 🥈 pysentry-osv | 0.436s | 1.58x |
|  pysentry-pypa | 0.882s | 3.18x |
|  pysentry-all-sources | 0.992s | 3.58x |
|  pip-audit-default | 8.109s | 29.27x |

#### Memory Usage Comparison

| Tool Configuration | Peak Memory | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 8.33 MB | 1.00x |
| 🥈 pysentry-osv | 10.53 MB | 1.26x |
|  pip-audit-default | 44.61 MB | 5.36x |
|  pysentry-pypa | 47.93 MB | 5.75x |
|  pysentry-all-sources | 82.66 MB | 9.93x |

### Large_Requirements Dataset - Cold Cache

#### Execution Time Comparison

| Tool Configuration | Execution Time | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 0.951s | 1.00x |
| 🥈 pysentry-osv | 1.183s | 1.24x |
|  pysentry-all-sources | 1.492s | 1.57x |
|  pysentry-pypa | 1.514s | 1.59x |
|  pip-audit-default | 17.498s | 18.39x |

#### Memory Usage Comparison

| Tool Configuration | Peak Memory | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-osv | 37.28 MB | 1.00x |
| 🥈 pysentry-pypi | 39.49 MB | 1.06x |
|  pip-audit-default | 48.36 MB | 1.30x |
|  pysentry-pypa | 85.48 MB | 2.29x |
|  pysentry-all-sources | 121.19 MB | 3.25x |

### Large_Requirements Dataset - Hot Cache

#### Execution Time Comparison

| Tool Configuration | Execution Time | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 0.880s | 1.00x |
| 🥈 pysentry-osv | 1.129s | 1.28x |
|  pysentry-pypa | 1.370s | 1.56x |
|  pysentry-all-sources | 1.466s | 1.67x |
|  pip-audit-default | 16.341s | 18.57x |

#### Memory Usage Comparison

| Tool Configuration | Peak Memory | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 9.28 MB | 1.00x |
| 🥈 pysentry-osv | 11.17 MB | 1.20x |
|  pip-audit-default | 47.85 MB | 5.16x |
|  pysentry-pypa | 53.70 MB | 5.79x |
|  pysentry-all-sources | 92.76 MB | 9.99x |

## Detailed Analysis

### Pysentry Performance

- **Execution Time:** Avg: 0.996s, Min: 0.277s, Max: 1.514s

- **Memory Usage:** Avg: 49.75 MB, Min: 8.33 MB, Max: 121.19 MB

- **Success Rate:** 100.0% (16/16)

### Pip-Audit Performance

- **Execution Time:** Avg: 12.714s, Min: 8.109s, Max: 17.498s

- **Memory Usage:** Avg: 46.66 MB, Min: 44.61 MB, Max: 48.36 MB

- **Success Rate:** 100.0% (4/4)